pub struct Game { /* private fields */ }Expand description
Deterministic GridWorld with a single unit and goal tile.
Implementations
Sourceimpl Game
impl Game
Sourcepub fn new(world_vector: Vec<Vec<char>>) -> Result<Self, GameError>
pub fn new(world_vector: Vec<Vec<char>>) -> Result<Self, GameError>
Construct a Game from a 2D character grid.
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Reset unit position and turn counter to the initial world configuration.
Sourcepub fn check_game_done(&self) -> bool
pub fn check_game_done(&self) -> bool
Whether the unit is currently on the goal tile.
Sourcepub fn world_configuration(&self) -> Vec<Vec<char>>
pub fn world_configuration(&self) -> Vec<Vec<char>>
Return a clone of the original world configuration.